/*
 *  /MathJax/localization/scn/FontWarnings.js
 *
 *  Copyright (c) 2009-2015 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("scn","FontWarnings",{version:"2.6.0",isLoaded:true,strings:{webFont:"MathJax sta adupirannu tipi di car\u00E0ttiri scarricati di Internet p'ammmustrari la matim\u00E0tica nta sta p\u00E0ggina. Scarricari sti tipi si pigghia tempu, dunca sta p\u00E0ggina si purr\u00ECa mpagginari cchi\u00F9 viloci si li tipi di car\u00E0ttiri p\u00E2 matim\u00E0tica f\u00F9ssiru istallati direttamenti nt\u00E2 cartella d\u00EE car\u00E0ttiri d\u00FB t\u00F2 sistema.",imageFonts:"MathJax sta adupirannu mm\u00E0ggini comu tipi di car\u00E0ttiri, mmeci di adupirari tipi di car\u00E0ttiri lucali o scarricati d'Internet. Stu fattu renni la mpagginazzioni cchi\u00F9 lenta d\u00FB s\u00F2litu, e quannu si stampa, la matim\u00E0tica purr\u00ECa nun aviri la risuluzzioni china cunzintuta d\u00E2 stampanti.",noFonts:"MathJax nun potti attruvari nu tipu di car\u00E0ttiri bonu p'ammustrari la matim\u00E0tica, e mancu sunnu dispun\u00ECbbili mm\u00E0ggini fatti a tipi di car\u00E0ttiri; pi chistu sta ripiegannu a l'adupirari li car\u00E0ttiri Unicode, nt\u00E2 spiranza chi lu t\u00F2 browser \u00E8 capaci d'ammustr\u00E0rili. P\u00F2 \u00E8ssiri ca certi car\u00E0ttiri nun sp\u00F9ntanu boni, o nun sp\u00F9ntanu propia.",webFonts:"Li cchi\u00F9 d\u00EE browser muderni pirm\u00E8ttinu di scarricari li tipi di car\u00E0ttiri d'Internet. Aggiurnannu lu t\u00F2 browser (o canci\u00E0nnulu) si purr\u00ECa migghiurari la qualit\u00E0 d\u00E2 matim\u00E0tica ca veni ammustrata nta sta p\u00E0ggina.",fonts:"MathJax po fari usu o d\u00EE [tipi di car\u00E0ttiri STIX](%1) o d\u00EE [tipi di car\u00E0ttiri TeX MathJax](%2). Sc\u00E0rrica e istalla unu di sti tipi pi fari funziunari megghiu MathJax.",STIXPage:"Sta p\u00E0ggina \u00E8 pruggittata pi fari usu d\u00EE [tipi di car\u00E0ttiri STIX](%1). Sc\u00E0rrica e istalla sti tipi pi fari funziunari megghiu MathJax.",TeXPage:"Sta p\u00E0ggina \u00E8 pruggittata pi fari usu d\u00EE [tipi di car\u00E0ttiri TeX MathJax](%1). Sc\u00E0rrica e istalla sti tipi pi fari funziunari megghiu MathJax."}});MathJax.Ajax.loadComplete("[MathJax]/localization/scn/FontWarnings.js");
